@@ -16,11 +16,11 @@ Alien::SDL - building, finding and using SDL binaries
 
 =head1 VERSION
 
-Version 1.436
+Version 1.437_2
 
 =cut
 
-our $VERSION = '1.437_1';
+our $VERSION = '1.437_2';
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
@@ -305,6 +305,9 @@ sub _sdl_config_via_script
     $val .= ' ' . join(' ', @add_libs) if scalar @add_libs;
     $val .= ' ' . Alien::SDL::ConfigData->config('additional_libs');
   }
+  elsif($param =~ /^(ld_shlib_map|ld_shared_libs|ld_paths)$/) {
+    $val = Alien::SDL::ConfigData->config('config')->{$param};
+  }
   return $val;
 }
 
